@@ -1,13 +1,10 @@
 import functools
 import itertools
 from collections import defaultdict
-from collections import deque
 
-from musictool import chromatic
 from musictool import config
 from musictool.chord import Chord
 from musictool.note import Note
-from musictool.note import SpecificNote
 from musictool.noteset import NoteSet
 from musictool.piano import Piano
 from musictool.util.color import hex_to_rgb
@@ -41,49 +38,38 @@ class Scale(NoteSet):
     }
     name_to_intervals = {v: k for k, v in intervals_to_name.items()}
 
-    _cache = {}
-
-    def __new__(
-        cls,
-        notes: frozenset[str | Note],
-        root: str | Note,
-    ):
-        key = notes, root
-        if instance := cls._cache.get(key):
-            return instance
-        instance = super().__new__(cls)
-        instance._long_init(notes, root)
-        cls._cache[key] = instance
-        return instance
-
-    # def __init__(
-    def _long_init(
+    def __init__(
         self,
         notes: frozenset[str | Note],
+        *,
         root: str | Note,
     ):
-        super().__init__(notes, root)
+        super().__init__(notes, root=root)
         self.kind = config.kinds.get(self.name)
-        if self.kind == 'diatonic':
-            self.triads = self._make_triads()
 
-        self.note_colors = {}
-        self.note_scales = {}
+        if self.kind is not None:
+            self.note_colors = {}
+            self.note_scales = {}
 
-        for note, scale in zip(self.notes_ascending, iter_scales(self.kind, start=self.name)):
-            self.note_colors[note] = hex_to_rgb(config.scale_colors[scale])
-            self.note_scales[note] = scale
+            for note, scale in zip(self.notes_ascending, iter_scales(self.kind, start=self.name)):
+                self.note_colors[note] = hex_to_rgb(config.scale_colors[scale])
+                self.note_scales[note] = scale
+
+            if self.kind == 'diatonic':
+                self.triads = self._make_nths(frozenset({0, 2, 4}))
+                self.sevenths = self._make_nths(frozenset({0, 2, 4, 6}))
+                self.ninths = self._make_nths(frozenset({0, 2, 4, 6, 8}))
+                self.notes_to_triad_root = {triad.notes: triad.root for triad in self.triads}
+                self.notes_to_seventh_root = {seventh.notes: seventh.root for seventh in self.sevenths}
+                self.notes_to_ninth_root = {ninth.notes: ninth.root for ninth in self.ninths}
 
         self.html_classes = ('card', self.name)
 
-    def _make_triads(self):
-        notes_deque = deque(self.notes_ascending)
-        triads = []
-        for _ in range(len(notes_deque)):
-            chord = Chord(frozenset({notes_deque[0], notes_deque[2], notes_deque[4]}), root=notes_deque[0])
-            triads.append(chord)
-            notes_deque.rotate(-1)
-        return tuple(triads)
+    def _make_nths(self, ns: frozenset[int]) -> tuple[Chord]:
+        return tuple(
+            Chord(frozenset(self.notes_ascending[(i + n) % len(self)] for n in ns), root=self.notes_ascending[i])
+            for i in range(len(self))
+        )
 
     def to_piano_image(self):
         return Piano(scale=self)._repr_svg_()
@@ -109,105 +95,6 @@ class Scale(NoteSet):
 # flake8: noqa
 
 
-class ScaleOld:
-    _cache = {}
-
-    def __new__(cls, root: str | Note, name: str):
-        key = root, name
-        if instance := cls._cache.get(key):
-            return instance
-        instance = super().__new__(cls)
-        instance._long_init(root, name)
-        cls._cache[key] = instance
-        return instance
-
-    def __getnewargs__(self):
-        """
-        tells pickle.dumps to pickle x in such a way that a pickle.loads
-        back from that string will use __new__ with the proper argument.
-        """
-        return self.root, self.name
-
-    def _long_init(self, root: str | Note, name: str):
-        if isinstance(root, str):
-            root = Note(root)
-        self.root = root
-        self.name = name
-        self.key = root, name
-        self.bits = name_2_bits[name]
-        self.notes = tuple(itertools.compress(chromatic.iterate(start_note=root), map(int, self.bits)))
-
-        # self.notes = tuple(itertools.compress(chromatic(root), map(int, self.bits)))
-        # print(self.notes)
-        self.chromatic_mask = ''.join(note.name if note in self.notes else '_' for note in chromatic.iterate(take_n=12))
-        # self.chromatic_bits = ''.join(str(int(note in self.notes)) for note in config.chromatic_notes) # from C (config.chromatic_notes[0])
-        # self.chromatic_bits = int(self.bits, base=2)
-        self.kind = config.kinds.get(name)
-        if self.kind == 'diatonic':
-            self.add_chords()
-
-        self.note_colors = {}
-        self.note_scales = {}
-
-        for note, scale in zip(self.notes, iter_scales(self.kind, start=self.name)):
-            self.note_colors[note] = hex_to_rgb(config.scale_colors[scale])
-            self.note_scales[note] = scale
-
-        self.html_classes = ('card', self.name)
-
-    def add_chords(self):
-        notes_deque = deque(self.notes)
-        chords = []
-        for _ in range(len(notes_deque)):
-            chord = Chord(frozenset({notes_deque[0], notes_deque[2], notes_deque[4]}), root=notes_deque[0])
-            chords.append(chord)
-            notes_deque.rotate(-1)
-        self.chords = tuple(chords)
-
-    def to_piano_image(self):
-        return Piano(scale=self)._repr_svg_()
-
-    def _chords_text(self):
-        x = 'chords:\n'
-        for i, chord in enumerate(self.chords, start=1):
-            x += f'{i} {chord} {chord.name}\n'
-        return x
-
-    def with_html_classes(self, classes: tuple):
-        prev = self.html_classes
-        self.html_classes = prev + classes
-        r = self._repr_html_()
-        self.html_classes = prev
-        return r
-
-    # def __format__(self, format_spec): raise No
-
-    # @functools.cached_property
-    def _repr_html_(self):
-        # <code>bits: {self.bits}</code><br>
-        # chords_hover = f"title='{self._chords_text()}'" if self.kind =='diatonic' else ''
-        chords_hover = ''
-        return f'''
-        <div class='{' '.join(self.html_classes)}' {chords_hover}>
-        <a href='{self.root.name}'><span class='card_header'><h3>{self.root.name} {self.name}</h3></span></a>
-        {self.to_piano_image()}
-        </div>
-        '''
-
-    def add_note(self, note: Note | SpecificNote, steps: int):
-        if type(note) is Note:
-            return self.notes[(self.notes.index(note) + steps) % len(self.notes)]
-        elif type(note) is SpecificNote:
-            octave, i = divmod(self.notes.index(note.abstract) + steps, len(self.notes))
-            return SpecificNote(self.notes[i], note.octave + octave)
-        else:
-            raise TypeError
-
-    def __eq__(self, other): return self.key == other.key
-    def __hash__(self): return hash(self.key)
-    def __repr__(self): return f'Scale({self.root} {self.name})'
-
-
 class ComparedScales:
     '''
     this is compared scale
@@ -257,7 +144,7 @@ class ComparedScales:
                     hex_to_rgb(config.chord_colors[chord.name]),
                     config.BLUE_COLOR if chord in self.shared_triads else config.BLACK_COLOR,
                     config.BLUE_COLOR if chord in self.shared_triads else config.BLACK_COLOR,
-                    chord.str_chord,
+                    str(chord),
                 )
                 for chord in self.right.triads
             } if self.right.kind == 'diatonic' else dict(),
